(function () {
  'use strict';

  var css = ".mfe-highlighter-container {\n  position: absolute;\n  display: block;\n}\n.mfe-highlighter-container * {\n  pointer-events: none !important;\n}\n\n.mfe-highlighter {\n  position: absolute;\n  border: none;\n  z-index: 1;\n  box-sizing: border-box;\n  padding: 4px;\n}\n.mfe-highlighter::before {\n  background: linear-gradient(to left top, var(--mfe-highlighter-secondary-color, #4fedeb), var(--mfe-highlighter-primary-color, #0958ee));\n  border-radius: inherit;\n  content: \"\";\n  inset: 0;\n  -webkit-mask: linear-gradient(#fff 0 0) content-box, linear-gradient(#fff 0 0);\n  -webkit-mask-composite: xor;\n  mask-composite: exclude;\n  padding: 2px;\n  position: absolute;\n  z-index: -1;\n}\n\n.mfe-highlighter-border {\n  position: absolute;\n}\n\n.mfe-highlighter-bar {\n  position: absolute;\n  z-index: 15500;\n  left: 0;\n  top: -34px;\n  padding: 8px 0;\n}\n.mfe-highlighter-bar .mfe-highlighter-bar-content {\n  border-radius: 0.5em;\n  display: flex;\n  white-space: nowrap;\n  width: fit-content;\n}\n.mfe-highlighter-bar .mfe-highlighter-bar-content > a {\n  background: var(--mfe-highlighter-primary-color, #0958ee);\n  line-height: 1.5;\n  margin-right: 0.125em;\n  padding: 0 0.5em;\n  transform: translateZ(0);\n  transition: filter, background-color 0.3s ease;\n}\n.mfe-highlighter-bar .mfe-highlighter-bar-content > a:first-child {\n  border-bottom-left-radius: 0.5em;\n  border-top-left-radius: 0.5em;\n}\n.mfe-highlighter-bar .mfe-highlighter-bar-content > a:last-child {\n  border-bottom-right-radius: 0.5em;\n  border-top-right-radius: 0.5em;\n  margin-right: 0;\n}\n\n/*# sourceMappingURL=mfe-highlighter.css.map */\n";

  // @ts-ignore
  function injectCSS() {
      const style = document.createElement('style');
      style.innerHTML = css;
      document.head.appendChild(style);
  }
  function createInfoBar(org, owner, mfeName, mfeVersion) {
      const infoBar = document.createElement('div');
      infoBar.className = 'mfe-highlighter-container';
      const version = mfeVersion ? `<span>@v${mfeVersion}</span>` : '';
      infoBar.innerHTML = `
    <div class="mfe-highlighter">
      <div class="mfe-highlighter-border"></div>
      <div class="mfe-highlighter-bar">
        <div class="mfe-highlighter-bar-content">
          <a>&#127970; ${org}</a>
          <a>
            <span>&#128101; ${owner}.${mfeName}</span>
            ${version}
          </a>
        </div>
      </div>
    </div>
  `;
      return infoBar;
  }
  function init(options = { org: '@mfe-pro', primaryColor: '#4fedeb', secondaryColor: '#0958ee' }) {
      injectCSS();
      const { primaryColor = '#4fedeb', secondaryColor = '#0958ee' } = options;
      document.documentElement.style.setProperty('--mfe-highlighter-primary-color', primaryColor);
      document.documentElement.style.setProperty('--mfe-highlighter-secondary-color', secondaryColor);
      const elements = document.querySelectorAll('[data-mfe-highlighter="true"]');
      elements.forEach((element) => {
          const name = element.getAttribute('data-mfe-name');
          const owner = element.getAttribute('data-mfe-owner');
          const version = element.getAttribute('data-mfe-version');
          if (!name || !owner)
              return;
          element.style.setProperty('--mfe-highlighter-primary-color', primaryColor);
          element.style.setProperty('--mfe-highlighter-secondary-color', secondaryColor);
          element.addEventListener('mouseover', () => {
              var _a;
              const container = createInfoBar(options.org, owner, name, version);
              const { top, left, right, bottom, height, width } = element.getBoundingClientRect();
              const infoBar = container.querySelector('.mfe-highlighter-bar');
              const infoBarHeight = 40;
              (_a = element.parentNode) === null || _a === void 0 ? void 0 : _a.insertBefore(container, element.nextSibling);
              if (infoBar) {
                  infoBar.style.top = top < infoBarHeight ? `${height - 5}px` : '-34px';
              }
              const firstChild = container.firstElementChild;
              if (firstChild) {
                  firstChild.style.width = `${width}px`;
                  firstChild.style.height = `${height}px`;
              }
              container.style.top = `${top}px`;
              container.style.left = `${left}px`;
              container.style.right = `${right}px`;
              container.style.bottom = `${bottom}px`;
          });
          element.addEventListener('mouseout', () => {
              var _a;
              (_a = document.querySelector('.mfe-highlighter-container')) === null || _a === void 0 ? void 0 : _a.remove();
          });
      });
  }

  window.MFEHighlighter = {
      init,
  };

})();
